# BotCity Discord Plugin - Python

## 🤖 Computer-vision based UI Automation

Recognize and interact with UI elements using state-of-art computer vision module.

Operate any UI interface independent of the technology or platform (desktop, web, terminal).

## 🐍 Generate Python Code while Interacting with your UI

Use our Development Tool alongside your favorite IDE to select UI components and generate python code.

[![BotCity Studio](https://developers.botcity.dev/github/readme/studio/studio.gif)](https://documentation.botcity.dev/studio/)

[SIGN UP](https://developers.botcity.dev/app/signup) and download our tools.


## 🚀 Getting Started

### 📦 Prerequisites
* Python 3.7+
* discord-webhook 0.15.0+

### 💫 Installing

```bash
pip install botcity-discord-plugin
```

### ⭐ Using the Plugin

[![First Automation](https://developers.botcity.dev/github/readme/python-plugins/discord-plugin.png)](https://documentation.botcity.dev/plugins/)

## 📚 Documentation

Documentation is available at https://documentation.botcity.dev/plugins.

## 💻 Developers Portal

[![Developers Portal](https://developers.botcity.dev/github/readme/portal.png)](https://documentation.botcity.dev/)

## 💬 Forum

[![Forum](https://developers.botcity.dev/github/readme/forum.png)](https://community.botcity.dev/)

## 🌎 BotCity Automation Platform
BotCity is a platform to develop, deploy, manage and maintain automations. Automations can be developed in Python or Java using open-source libraries that are market standard.

### 1️⃣  All in One Platform
Develop, deploy, manage and scale your Automation Ops using All in One platform that provides task queue, runtime environment management, reports, alerts, logs and much more.

[![BotCity Maestro](https://developers.botcity.dev/github/readme/maestro/maestro.png)](https://documentation.botcity.dev/maestro/)

### 2️⃣  Deploy with a Single Line

Use BotCity command-line interface (CLI) to deploy your bot into a runtime environment with a single line:

[![BotCity CLI](https://developers.botcity.dev/github/readme/cli/botcli.gif)](https://documentation.botcity.dev/cli/)

### 3️⃣  Manage your Task Queue

[![BotCity Maestro Task Queue](https://developers.botcity.dev/github/readme/maestro/tasks.png)](https://documentation.botcity.dev/maestro/features/new-task/)

### 4️⃣  Manage your Runtime Environments

[![BotCity Maestro Machines](https://developers.botcity.dev/github/readme/maestro/machines.png)](https://documentation.botcity.dev/maestro/features/runners/)

### 5️⃣  Create Alerts and Reports from the Automation Execution

[![BotCity Maestro Alerts](https://developers.botcity.dev/github/readme/maestro/alerts.png)](https://documentation.botcity.dev/maestro/features/alerts/)

### 6️⃣  Create Google Data Studio Dashboards

[![BotCity Maestro Dashboards](https://developers.botcity.dev/github/readme/maestro/dashboard.png)](https://documentation.botcity.dev/maestro/features/dashboards/)

### 7️⃣  Create your Community Account

We have a community account for hobbyists and students. Just signup and start automating.

[![Sign Up](https://developers.botcity.dev/github/readme/signup.png)](https://developers.botcity.dev/app/signup)


## ⛑ Support

### 📢 Contact us

If you have questions or comments in general about the framework, we want to know.

You can choose between the channels the one that best fit you:

- [BotCity Community](<https://community.botcity.dev>) (Public)

